pub fn isolate<'a>() -> IsolateOptionsFormer<'a>Expand description
String tools.
Function to split a string with some delimeter.
It produces former. To convert former into options and run algorithm of splitting call perform().
pub fn isolate<'a>() -> IsolateOptionsFormer<'a>String tools.
Function to split a string with some delimeter.
It produces former. To convert former into options and run algorithm of splitting call perform().